package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````7",```````!``````````,BA````
M`````````$``.``(`$``&@`9``8````%````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````;`````````!L``````````0`````````!````
M!0```````````````````````````````````+23````````M),`````````
M``$```````$````&````&)L````````8FP$``````!B;`0``````:`4`````
M``"0%0```````````0```````@````8````PFP```````#";`0``````,)L!
M```````@`@```````"`"````````"``````````$````!````!P"````````
M'`(````````<`@```````$0`````````1``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0````8FP```````!B;`0``````&)L!``````#H!```````
M`.@$`````````0`````````O;&EB+VQD+6QI;G5X+6%A<F-H-C0N<V\N,0``
M!````!`````!````1TY5```````#````!P`````````$````%`````,```!'
M3E4`IM)Q#F!:S@^]RD%!>.I9LQ\F^>`1````40````0````(````(1`0``7`
M!(0H`A`!@(9`@((I``0)(`2)B*`81;H$`@A1````4@```%8```!;````7```
M`&,```!D````90```&<```!H`````````&H```!K````;````&X`````````
M``````&O-.ANQ=\?ZM/O#L[>1RUK?YI\+L6;MG94/)0@_^0.N(WQ#M5DU'S9
M<5@<XD?&`:Q+X\"ZXY)\6.^7><+E/RSZH6Q@LP&+;VL)0]9GK\QF0D75[(D'
M<-,-%.*>VLWCGC-BV^T-.I<+?ZF<F[[:5QOAIP(*H^#[20``````````````
M`````````````````````````````P`+`.@<````````````````````````
M`P`3`"B;`0````````````````#3`@``$@````````````````````````!7
M`P``$@````````````````````````"C`@``$@``````````````````````
M``"J`@``$@````````````````````````!)`P``$@``````````````````
M``````!*`@``$@`````````````````````````1````(```````````````
M``````````#[`@``$@`````````````````````````3`P``$@``````````
M```````````````Z`P``(@`````````````````````````,`P``$@``````
M``````````````````#S`@``$@````````````````````````#(````$@``
M```````````````````````%`P``$0````````````````````````"7`0``
M$@`````````````````````````X`@``$@````````````````````````!7
M`@``$@````````````````````````"8````$@``````````````````````
M```@`0``$@`````````````````````````<`P``$@``````````````````
M``````"<`@``$@````````````````````````"^`0``$@``````````````
M```````````5`0``$0````````````````````````#:`@``$@``````````
M``````````````![`0``$@````````````````````````#W````$0``````
M``````````````````!)`0``$@````````````````````````!/`@``$@``
M``````````````````````!M`P``$@````````````````````````"Q`@``
M$@````````````````````````#6````$@````````````````````````#%
M`0``$@`````````````````````````A`@``$@``````````````````````
M``"R`0``$@````````````````````````#O`0``$@``````````````````
M``````"'`@``$@````````````````````````!@`@``$@``````````````
M``````````!I`@``$@`````````````````````````#`@``$@``````````
M``````````````!7`0``$@`````````````````````````M````(```````
M``````````````````"?`P``$0````````````````````````"``P``(0``
M``````````````````````"/`@``$@````````````````````````!?`P``
M$@````````````````````````#0`0``$0````````````````````````!X
M````$@````````````````````````#%`@``$@``````````````````````
M``!F`P``$@`````````````````````````>!```$@``````````````````
M``````"_`@``$@````````````````````````"G````$@``````````````
M``````````"S````$@````````````````````````!P`0``$@``````````
M``````````````#H`@``$@`````````````````````````V`0``$@``````
M```````````````````E`0``$@````````````````````````!J````$@``
M```````````````````````P`P``$@`````````````````````````J`0``
M$@````````````````````````"G`0``$@`````````````````````````$
M`0``$@`````````````````````````I`P``$@``````````````````````
M``")`0``$@````````````````````````"'````$@``````````````````
M```````I`@``$@````````````````````````"5`@``$@``````````````
M``````````!_`P``$0````````````````````````"!`P``$0``````````
M```````````````\````(``````````````````````````)`@``$@``````
M``````````````````#H````$@````````````````````````!G`0``$@``
M``````````````````````"X`@``$@````````````````````````!0````
M(``````````````````````````0`@``$@````````````````````````!Z
M`@``$@````````````````````````"!`@``$@``````````````````````
M``#3`P``$``7`*BP`0`````````````````G!```$@`-`#!2````````B```
M``````#U`P``$@`.`%13``````````````````!,!```$@`-`"!%````````
M<`D```````!Z`P``$@`-`"`A````````/`(```````#[`P``$@`-`#`^````
M````!`````````#$`P``$``7`("@`0````````````````"Z!```$@`-`#@^
M````````$`(```````"T!```$@`+`.@<``````````````````#G!```$@`-
M`)!.````````G`,```````"X`P``$``7`("@`0`````````````````S!```
M$@`-`$A`````````(`````````!F!```$0`/`&A3````````!`````````#F
M`P``$``7`*BP`0````````````````#>`P``$``7`*BP`0``````````````
M``"R!```$@`-`+@\````````.`````````#'!```$@`-`"A$````````]```
M``````#9!```$@`-`&A#````````F`````````!9!```$``6``"@`0``````
M``````````!`!```$@`-`&A`````````,`$```````"Q`P``$``6`("@`0``
M``````````````";!```$0`6`'B@`0``````"`````````#K`P``$@`-`%!3
M````````!`````````"+!```$@`-`-A2````````>`````````!?!```$@`-
M`%PC``````````````````!;!```(``6``"@`0`````````````````,!```
M$@`-``!$````````*`````````#2`P``$``7`*BP`0````````````````!U
M!```$@`-`$@]````````Y`````````"E!```$@`-`)A!````````T`$`````
M````;&EB<&5R;"YS;RXU+C(V`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L
M90!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%])5$U?<F5G
M:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET
M,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V
M`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R
M<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W
M6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R
M;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V
M`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E
M=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA
M;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8G!T:')E860N<V\N
M,`!P=&AR96%D7V=E='-P96-I9FEC`&-L;W-E`&]P96XV-`!?7V5R<FYO7VQO
M8V%T:6]N`&QS965K-C0`<F5A9`!L:6)C+G-O+C8`7U]R96=I<W1E<E]A=&9O
M<FL`97AI=`!S=')N8VUP`%]?<W1R9'5P`&-L;W-E9&ER`%]?<W1A8VM?8VAK
M7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`86)O<G0`;65M8VAR`&=E='!I
M9`!S=')T;VL`<W1R;&5N`&UE;7-E=`!S=')S='(`<FUD:7(`7U]F<')I;G1F
M7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`
M7U]X<W1A=#8T`'-T9&5R<@!G971U:60`<F5A9&QI;FL`7U]M96UC<'E?8VAK
M`'-T<F-H<@!R96%D9&ER-C0`7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F7V-H
M:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E
M;G9I<F]N`&QD+6QI;G5X+6%A<F-H-C0N<V\N,0!?7W-T86-K7V-H:U]G=6%R
M9`!?961A=&$`7U]B<W-?<W1A<G0`7U]B<W-?<W1A<G1?7P!?7V)S<U]E;F1?
M7P!?7V5N9%]?`%]E;F0`7U]L:6)C7V-S=5]F:6YI`'!A<E]C=7)R96YT7V5X
M96,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``<&%R
M7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!?7V1A=&%?<W1A
M<G0`7TE/7W-T9&EN7W5S960`<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB
M8U]C<W5?:6YI=`!M>5]P87)?<&P`<&%R7VEN:71?96YV`'AS7VEN:70`<&%R
M7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`6%-?
M26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N,3<``````````@`"``(``@`"
M``(````"``(``@`"``(````"`````@`"```````"``(``@````(`````````
M`@`"``(```````,````#``(``@`"``,```````0``@`"``(```````(``@`"
M``(``````````@````(````"``````````(```````,``@`"``(````#````
M```"`````P`"``(``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$````!``$`B0,``!`````@````
MEY&6!@``!`#]!`````````$``0#?`0``$````"````"7D98&```#`/T$````
M`````0`!`"X"```0`````````)>1E@8```(`_00````````8FP$```````,$
M````````:"0````````@FP$```````,$````````("0```````!PGP$`````
M``,$````````4%,```````"XGP$```````,$````````"*`!``````#(GP$`
M``````,$````````V%(```````#8GP$```````,$````````("$````````(
MH`$```````,$````````"*`!```````8H`$```````,$````````<%<`````
M```@H`$```````,$````````$%0````````PH`$```````,$`````````%4`
M```````XH`$```````,$````````4%<```````!`H`$```````,$````````
M6%<```````!(H`$```````,$````````8%<```````!0H`$```````,$````
M````:%<```````!@H`$```````,$````````.%<```````!HH`$```````,$
M````````0%<```````!XH`$```````,$````````>%<```````!XGP$`````
M``$$```)``````````````"`GP$```````$$```,``````````````"(GP$`
M``````$$```0``````````````"0GP$```````$$```1``````````````"8
MGP$```````$$```9``````````````"@GP$```````$$```<````````````
M``"HGP$```````$$```K``````````````"PGP$```````$$```L````````
M``````#`GP$```````$$```P``````````````#0GP$```````$$```Z````
M``````````#@GP$```````$$``!#``````````````#HGP$```````$$``!'
M``````````````#PGP$```````$$``!(``````````````#XGP$```````$$
M``!-``````````````!HG0$```````($```#``````````````!PG0$`````
M``($```$``````````````!XG0$```````($```%``````````````"`G0$`
M``````($```&``````````````"(G0$```````($```'``````````````"0
MG0$```````($```(``````````````"8G0$```````($```*````````````
M``"@G0$```````($```+``````````````"HG0$```````($```,````````
M``````"PG0$```````($```-``````````````"XG0$```````($```.````
M``````````#`G0$```````($```/``````````````#(G0$```````($```2
M``````````````#0G0$```````($```3``````````````#8G0$```````($
M```4``````````````#@G0$```````($```5``````````````#HG0$`````
M``($```6``````````````#PG0$```````($```7``````````````#XG0$`
M``````($```8````````````````G@$```````($```:```````````````(
MG@$```````($```;```````````````0G@$```````($```=````````````
M```8G@$```````($```>```````````````@G@$```````($```?````````
M```````HG@$```````($```@```````````````PG@$```````($```A````
M```````````XG@$```````($```B``````````````!`G@$```````($```C
M``````````````!(G@$```````($```D``````````````!0G@$```````($
M```E``````````````!8G@$```````($```F``````````````!@G@$`````
M``($```G``````````````!HG@$```````($```H``````````````!PG@$`
M``````($```I``````````````!XG@$```````($```J``````````````"`
MG@$```````($```K``````````````"(G@$```````($```N````````````
M``"0G@$```````($```O``````````````"8G@$```````($```Q````````
M``````"@G@$```````($```R``````````````"HG@$```````($```S````
M``````````"PG@$```````($```T``````````````"XG@$```````($```U
M``````````````#`G@$```````($```V``````````````#(G@$```````($
M```W``````````````#0G@$```````($```X``````````````#8G@$`````
M``($```Y``````````````#@G@$```````($```[``````````````#HG@$`
M``````($```\``````````````#PG@$```````($```]``````````````#X
MG@$```````($```^````````````````GP$```````($```_````````````
M```(GP$```````($``!````````````````0GP$```````($``!!````````
M```````8GP$```````($``!"```````````````@GP$```````($``!$````
M```````````HGP$```````($``!%```````````````PGP$```````($``!)
M```````````````XGP$```````($``!*``````````````!`GP$```````($
M``!+``````````````!(GP$```````($``!,``````````````!0GP$`````
M``($``!.``````````````!8GP$```````($``!/``````````````!@GP$`
M``````($``!0``````````````#]>[^I_0,`D:D!`)3]>\&HP`-?U@````#P
M>[^IT```D!&R1OD0@C61(`(?UA\@`]4?(`/5'R`#U=```)`1MD;Y$*(UD2`"
M'];0``"0$;I&^1#"-9$@`A_6T```D!&^1OD0XC61(`(?UM```)`1PD;Y$`(V
MD2`"'];0``"0$<9&^1`B-I$@`A_6T```D!'*1OD00C:1(`(?UM```)`1SD;Y
M$&(VD2`"'];0``"0$=)&^1""-I$@`A_6T```D!'61OD0HC:1(`(?UM```)`1
MVD;Y$,(VD2`"'];0``"0$=Y&^1#B-I$@`A_6T```D!'B1OD0`C>1(`(?UM``
M`)`1YD;Y$"(WD2`"'];0``"0$>I&^1!"-Y$@`A_6T```D!'N1OD08C>1(`(?
MUM```)`1\D;Y$((WD2`"'];0``"0$?9&^1"B-Y$@`A_6T```D!'Z1OD0PC>1
M(`(?UM```)`1_D;Y$.(WD2`"'];0``"0$0)'^1`".)$@`A_6T```D!$&1_D0
M(CB1(`(?UM```)`1"D?Y$$(XD2`"'];0``"0$0Y'^1!B.)$@`A_6T```D!$2
M1_D0@CB1(`(?UM```)`1%D?Y$*(XD2`"'];0``"0$1I'^1#".)$@`A_6T```
MD!$>1_D0XCB1(`(?UM```)`1(D?Y$`(YD2`"'];0``"0$29'^1`B.9$@`A_6
MT```D!$J1_D00CF1(`(?UM```)`1+D?Y$&(YD2`"'];0``"0$3)'^1"".9$@
M`A_6T```D!$V1_D0HCF1(`(?UM```)`1.D?Y$,(YD2`"'];0``"0$3Y'^1#B
M.9$@`A_6T```D!%"1_D0`CJ1(`(?UM```)`11D?Y$"(ZD2`"'];0``"0$4I'
M^1!".I$@`A_6T```D!%.1_D08CJ1(`(?UM```)`14D?Y$((ZD2`"'];0``"0
M$59'^1"B.I$@`A_6T```D!%:1_D0PCJ1(`(?UM```)`17D?Y$.(ZD2`"'];0
M``"0$6)'^1`".Y$@`A_6T```D!%F1_D0(CN1(`(?UM```)`1:D?Y$$([D2`"
M']:P``#P$6Y'^1!B.Y$@`A_6L```\!%R1_D0@CN1(`(?UK```/`1=D?Y$*([
MD2`"']:P``#P$7I'^1#".Y$@`A_6L```\!%^1_D0XCN1(`(?UK```/`1@D?Y
M$`(\D2`"']:P``#P$89'^1`B/)$@`A_6L```\!&*1_D00CR1(`(?UK```/`1
MCD?Y$&(\D2`"']:P``#P$9)'^1""/)$@`A_6L```\!&61_D0HCR1(`(?UK``
M`/`1FD?Y$,(\D2`"']:P``#P$9Y'^1#B/)$@`A_6L```\!&B1_D0`CV1(`(?
MUK```/`1ID?Y$"(]D2`"']:P``#P$:I'^1!"/9$@`A_6L```\!&N1_D08CV1
M(`(?UK```/`1LD?Y$((]D2`"'];]>[FI_0,`D?-3`:FS``#P]5L"J;0``/!C
MVD?Y]QL`^:*'!*FB(P&19`!`^:0W`/D$`(#2H%\`N:%#`9&@<P&1B/__EZ``
M`/"B``#P`/!'^4+H1_GA`P*J4`P`E*```/``T$?Y``!`.6`!`#5-__^7P@``
MD$!0`/G@#0"TM```\!C__Y>`SD?Y``!`N5'__Y<?A"0YE,Y'^8`"0+E-__^7
M`>A3.2$`'S(!Z!,Y@`)`N4C__Y<"Z%,YH5]`N0,`_))"```R`N@3.2$4`!$A
M?$"3/P`#ZT@)`%0@\'W3.?__EZ0K0/G!``"0U```D(4B`I$F/$#Y`P``\(>$
M0/ACH!R1HE]`N0$``/`'#`"I(<`<D8,`@%(&!`&IHP0`N5\$`'&@!`#YH0"`
M4N<`@))#``,+[0``5.7,(8N&A$#X(00`$3\``VL&:"7X8?__5)8B`I$%S".+
MXP,`J@$``+`$`(#20@P`$<`.0/DAP#.1OX`?^'#__Y?U`P`J(`,`-)8B`I&W
MDP&1P`Y`^>[^_Y<```#PX0,7J@!`$I'0!`"4@`(`M)0B`I&`#D#YTO[_EU7_
M_Y=SVD?YX`,5*J(W0/EA`D#Y00`!RF$#`+7S4T&I]5M"J?<;0/G]>\>HP`-?
MUL`.0/ET__^7]0,`*N7__Q?`"D#Y``$`M,<+`)3J__\7H0``\````/``@!R1
M(>!'^2W__Y<```#PX0,7J@!@$)&O!`"4P`H`^>#[_[2Z"P"4W?__%_3^_Y<@
M`(!2AO[_EQT`@-(>`(#2Y0,`JN$#0/GB(P"1Y@,`D:```/``[$?YHP``\&/D
M1_FD``#PA+A'^<'^_Y?T_O^7H```\`#41_E```"T[/[_%\`#7];!``"0(0`"
MD2$<`)'```"0```"D2$``,L_.`#QJ0``5*$``/`AO$?Y00``M"``'];``U_6
M'R`#U<$``)#```"0(0`"D0```I$A``#+(?Q#DR'\08LA_$&3P0``M*(``/!"
M_$?Y8@``M$``']8?(`/5P`-?UA\@`]7]>[ZI_0,`D?,+`/G3``"08`)".4`!
M`#6@``#P`,!'^8```+3```"0``1`^57^_Y?6__^7(`"`4F`"`CGS"T#Y_7O"
MJ,`#7]:@``#P`*`LD0$`0/EA``"UVO__%Q\@`]6A``#P(?A'^8'__[3]>[^I
M_0,`D2``/];]>\&HT?__%_^#"M&H``#P!.``D0G@`9']>P"I_0,`D:)C`)$!
MV4?Y1R``D2,`0/FC3P'Y`P"`TH$`0+F#A$#X(0C`6N&`'_B?``GK8?Q@TV7\
M:-,FW'C3I1QXDB$<"%/&''"2(0`&JJ/@0ZHA``.JX00!^"'^_U1&``B11`!`
M^4(@`)%#!$#Y11Q`^4$P0/EC``3*WP`"ZR$`!<HA``/*(_Q?TV$$`:HA?$"2
M03P`^6'^_U0$%$"IH`!GG@8D0:G"`&>>(0%GGJO\0M-K>06JH@]`^4`<82YK
M?4"280%GGB$SC])!4*OR0P`!BX+\6],*$$#Y0A0$JHW\0M,'`&:>@`!GGJUY
M!*H@'&(NKGU`DJT70/GB0"*+IQ-`^4(``XNM`0&+0@`*B^<``8L#`&:>3'Q`
MDD(`#HIC``F+9P`'BX/]6]-C%`RJXT`CBV<!+(KB``*J9WQ`DD(`!HM-``V+
M@OU"TTQX#*KB_%O30A0'JHQ]0)*B02*+K1M`^6,`#(JO`0&+S0$GBJ,!`ZIM
M``N+X_Q"TV=X!ZI+?$"2YWQ`DJT!#XM#``>*8OU;TT(4"ZJB02*+K1]`^:\!
M`8N-`2N*K0$#JF/]0M.M`0Z+:W@+JJT!#XMK?4"23WQ`DD,`"XKB_5O30A0/
MJJ)!(HNM(T#YK@$!B^T`+XJC`0.J;``,BXT!#HOL_4+3C'D/JDY\0)*,?4"2
M0P`,BL+]6]-"%`ZJHD$BBZTG0/FO`0&+;0$NBJ,!`ZIG``>+[0`/B\?]0M/G
M>`ZJ3WQ`DN=\0))#``>*XOU;TT(4#ZJB02*+K2M`^:X!`8N-`2^*HP$#JFL`
M"XMM`0Z+Z_U"TVMY#ZI.?$"2:WU`DD,`"XK"_5O30A0.JJ)!(HNM+T#YKP$!
MB^T`+HJC`0.J;``,BXT!#XO,_4+3C'D.JD]\0)*,?4"20P`,BN+]6]-"%`^J
MHD$BBZTS0/FN`0&+;0$OBJ,!`ZIG``>+[0`.B^?]0M/G>`^J3GQ`DN=\0))#
M``>*POU;TT(4#JJB02*+K3=`^:\!`8N-`2Z*HP$#JFL`"XMM`0^+R_U"TVMY
M#JI/?$"2:WU`DD,`"XKB_5O30A0/JJ)!(HNM.T#YK@$!B^T`+XJC`0.J;``,
MBXT!#HOL_4+3C'D/JDY\0)*,?4"20P`,BL+]6]-"%`ZJHD$BBZT_0/FO`0&+
M;0$NBJ,!`ZIG``>+[0`/B\?]0M/G>`ZJ3WQ`DN=\0))#``>*XOU;TT(4#ZJB
M02*+K4-`^:X!`8N-`2^*HP$#JFL`"XMM`0Z+Z_U"TVMY#ZI.?$"2:WU`DJ]'
M0/E#``N*POU;TT(4#JKO`0&+HD$BB^T`+HJC`0.J37Q`DFP`#(O#_4+3;G@.
MJHP!#XO.?4"2KTM`^4,`#HJB_5O30A0-JN\!`8N"02*+;`$MBH,!`ZI,?$"2
M9P`'BZ/]0M-M>`VJ[P`/BZU]0)*G3T#Y0P`-BH+]6]-"%`RJXD$BB^\``8O'
M`2R*YP`#JH/]0M-L>`RJYP`+BXQ]0))+?$"20P`,BF+]6]/G``^+0A0+JN)`
M(HNG4T#Y[P`!BZ<!*XKC``.J8P`.BTY\0))G``^+8_U"TVMX"ZK#_5O38Q0.
MJFM]0)+C0".+IU=`^4(`"XKO``&+AP$NBN(``JI'``V+8GQ`DLW]0M/G``^+
MKGD.JDW\6].M%0*JSWU`DN=`+8NM6T#Y8P`/BJT!`8MA`2**(0`#JN-\0)(A
M``R+</Q;TR$`#8M-_$+3K7D"JA`6`ZK"`0W*,$`PBT(`!TJG7T#Y#GY`DB%T
MG=(AVZWR0@`+B^<``8O,_5O30@`'BXP5#JI,0"R+8OQ"TT-X`ZJB8T#YIP$#
MRN<`$$I"``&+YP`/BX]]0)+K_5O3YP`"BVL5#ZJB9T#YZT`KB\?]0M/G>`ZJ
M3@`!BV(`!\I"``Q*0D`MBZUK0/E"``Z+;GU`DLS]6].M`0&+C!4.JDQ`+(OB
M_4+30G@/JN\``LKK`0M*8T$CBV,`#8N-?4"2J_U;TVL5#:IK0"N+P_U"TV-X
M#JJN;T#Y3P`#RNP!#$K.`0&+AT$GB^<`#HMN?4"2S/U;TXP5#JKL0"R+I_U"
MT^=X#:JM<T#Y;P`'RNL!"TJM`0&+8D$BBT(`#8N-?4"2J_U;TVL5#:I+0"N+
MPOU"TT)X#JJN=T#Y[P`"RNP!#$K.`0&+@T$CBV,`#HMN?4"2S/U;TXP5#JIL
M0"R+H_U"TV-X#:JM>T#Y3P`#RNL!"TJM`0&+9T$GB^<`#8N-?4"2J_U;TVL5
M#:KK0"N+Q_U"T^=X#JJN?T#Y;P`'RNP!#$K.`0&+@D$BBT(`#HMN?4"2S/U;
MTXP5#JI,0"R+HOU"TT)X#:JM@T#Y[P`"RNL!"TJM`0&+8T$CBV,`#8N-?4"2
MJ_U;TVL5#:IK0"N+P_U"TV-X#JJNAT#Y3P`#RNP!#$K.`0&+AT$GB^<`#HMN
M?4"2S/U;TXP5#JKL0"R+I_U"T^=X#:JMBT#Y;P`'RNL!"TJM`0&+8D$BBT(`
M#8N-?4"2J_U;TVL5#:I+0"N+POU"TT)X#JJNCT#Y[P`"RNP!#$K.`0&+@T$C
MBV,`#HMN?4"2S/U;TXP5#JIL0"R+H_U"TV-X#:JMDT#Y3P`#RNL!"TJM`0&+
M9T$GB^<`#8N-?4"2J_U;TVL5#:KK0"N+Q_U"T^=X#JJNET#Y;P`'RNP!#$K.
M`0&+@D$BBT(`#HMN?4"2S/U;TXP5#JI,0"R+HOU"TT)X#:JMFT#Y[P`"RNL!
M"TJM`0&+8T$CBV,`#8N-?4"2J_U;T[#]0M-K%0VJ$'H-JFM`*XO#_4+38W@.
MJJZ?0/E/``/*;0`0RNP!#$K.`0&+AT$GB^<`#HMN?4"2S/U;TZL!"TJ,%0ZJ
M8D$BB^=`+(NL+U2IC`$!BVL!`8M"``R+['Q`DHW]6]./_4+3K14,JN]Y#*I-
M0"V+POU"TT)X#JH.`@+*QP$'2N-`(XMC``N+JWU`DF?]6]/G%`NJ8T`GBZ>K
M0/EL?$"2YP`!BT$`#\HA``U*COU;TR%`,(O.%0RJ(0`'BV?]0M/K>`NJ+D`N
MB^$!"ZJMKT#Y(0`#BN,!"XHA``,JQWU`DB)`(HN#_4+3@9N7TF-X#*IAX['R
MK`$!B^W\6]-"``R+K14'JJRS0/E"0"V+;0$#JJX!#HJ-`0&+;`$#BLP!#"I.
M?$"2C$$OBXP!#8OM_$+3IWD'JLW]6].M%0ZJC4$MBVP`!ZJ"`0**K+=`^8\!
M`8ML``>*3``,*L+]0M.+02N+0G@.JFP!#XNK?4"2;OU;T^\``HK.%0NJCD$N
MB^P``JJ,`0V*K;M`^8P!#RJM`0&+@T$CBVP`#8O#?4"2;?U"TZMY"ZIM_%O3
MK14#JD\`"XJ-02V+3``+JHP!#HJNOT#YC`$/*LX!`8N'02>+[``.BZ=]0))N
M_$+3PWD#JN[\6]/.%0>J;P$#BHY!+HML`0.JC`$-BJW#0/F,`0\JK0$!BX)!
M(HM,``V+PGU`DNW\0M.G>0>J3?Q;TZT5`JIO``>*C4$MBVP`!ZJ,`0Z*KL=`
M^8P!#RK.`0&+BT$KBVP!#HNK?4"23OQ"T\)Y`JIN_5O3SA4+JN\``HJ.02Z+
M[``"JHP!#8JMRT#YC`$/*JT!`8N#02.+;``-B\-]0))M_4+3JWD+JFW\6].M
M%0.J3P`+BHU!+8M,``NJC`$.BJ[/0/F,`0\JS@$!BX=!)XOL``Z+IWU`DF[\
M0M/#>0.J[OQ;T\X5!ZIO`0.*CD$NBVP!`ZJ,`0V*K=-`^8P!#RJM`0&+@D$B
MBTP`#8O"?4"2[?Q"TZ=Y!ZI-_%O3K14"JF\`!XJ-02V+;``'JHP!#HJNUT#Y
MC`$/*LX!`8N+02N+;`$.BZM]0))._$+3PGD"JF[]6]/.%0NJ[P`"BHY!+HOL
M``*JC`$-BJW;0/F,`0\JK0$!BX-!(XML``V+PWU`DFW]0M.K>0NJ;?Q;TZT5
M`ZI/``N*C4$MBTP`"ZJ,`0Z*KM]`^8P!#RK.`0&+AT$GB^P`#HNG?4"2;OQ"
MT\-Y`ZKN_%O3SA4'JF\!`XJ.02Z+;`$#JHP!#8JMXT#YC`$/*JT!`8N"02*+
M3``-B\)]0)+M_$+3IWD'JDW\6].M%0*J;P`'BHU!+8ML``>JC`$.BJ[G0/F,
M`0\JS@$!BXM!*XML`0Z+JWU`DD[\0M/">0*J;OU;T\X5"ZKO``**CD$NB^P`
M`JJ,`0V*K>M`^8P!#RJM`0&+@T$CBVP`#8O#?4"2;?U"TZMY"ZIM_%O3K14#
MJD\`"XJ,02V+30`+JJT!#HJN[T#YK0$/*H]]0)*G02>+;?Q"TZ-Y`ZK.`0&+
M[?U;T^<`#HNM%0^J[4`MBV<!`ZKL``R*I_-`^>X``8MG`0.*AP$'*N)`(HM'
M``Z+KGU`DN+]0M/,_5O30G@/JHP5#JKL0"R+9P`"JF\``HKG``V*K?=`^><`
M#RKG0"N+CWU`DJT!`8O+_4+3YP`-B^W]6]-K>0ZJK14/JNU`+8M'``NJYP`,
MBJS[0/FN?4"2"-E'^8P!`8M!``N*X0`!*N?]0M,A0".+P_U;T^=X#ZHA``R+
M8Q0.JJS_0/DC0".+80$'RBT`#4K!.IC204RY\G!\0)*,`0&+HD$BBT(`#(L,
M_EO3C!40JDQ`+(O"_4+33W@.JJ(#0?E-``&+X@`/RD(``TH#_D+30D`KBV-X
M$*I"``V+C7U`DJO]6]/N`0/*:Q4-JLP!#$I+0"N+H@=!^6Y]0)*'02>+0@`!
MB\S]6]/G``*+C!4.JNQ`+(NB"T'YI_U"T^=X#:I-``&+8@`'RD(`"TI"0"^+
M0@`-BXU]0)*K_5O3:Q4-JDM`*XO"_4+30G@.JJX/0?GO``+*[`$,2LX!`8N#
M02.+8P`.BVY]0)+,_5O3C!4.JFQ`+(NC_4+38W@-JJT30?E/``/*ZP$+2JT!
M`8MG02>+YP`-BXU]0)*K_5O3:Q4-JNM`*XO'_4+3YW@.JJX70?EO``?*[`$,
M2LX!`8N"02*+0@`.BVY]0)+,_5O3C!4.JDQ`+(NB_4+30G@-JJT;0?GO``+*
MZP$+2JT!`8MC02.+8P`-BXU]0)*K_5O3:Q4-JFM`*XO#_4+38W@.JJX?0?E/
M``/*[`$,2LX!`8N'02>+YP`.BVY]0)+,_5O3C!4.JNQ`+(NG_4+3YW@-JJTC
M0?EO``?*ZP$+2JT!`8MB02*+0@`-BXU]0)*K_5O3:Q4-JDM`*XO"_4+30G@.
MJJXG0?GO``+*[`$,2LX!`8N#02.+8P`.BVY]0)+,_5O3C!4.JFQ`+(NC_4+3
M8W@-JJTK0?E/``/*ZP$+2JT!`8MG02>+YP`-BXU]0)*K_5O3:Q4-JNM`*XO'
M_4+3YW@.JJXO0?EO``?*[`$,2LX!`8N"02*+0@`.BVY]0)+,_5O3C!4.JDQ`
M+(NB_4+30G@-JJTS0?GO``+*ZP$+2JT!`8MC02.+8P`-BXU]0)*K_5O3:Q4-
MJFM`*XO#_4+38W@.JJXW0?E/``/*[`$,2LX!`8N'02>+YP`.BVY]0)+,_5O3
MC!4.JNQ`+(NG_4+3YW@-JJT[0?EO``?*ZP$+2JT!`8MB02*+0@`-BXU]0)*K
M_5O3:Q4-JDM`*XO"_4+33G@.JJ(_0?GO``[*[`$,2D(``8N#02.+8P`"BV)]
M0)),_%O3C!4"JFQ`+(NC_4+3;7@-JJ-#0?G/`0W*ZP$+2F,``8MG02>+YP`#
MBX-]0))K_%O3:Q4#JNM`*XM'_$+3XG@"JD<`"@NJ`0+*2@$,2FS\0M.#>0.J
M2D$NBT(``\IC``D+`YP!J4(`"TJG1T'Y0D`MBZ-+0?GG``&+2@$'BV$``8MG
M?4"20@`!B^'\6]/C_$+3(10'JF=X!ZHA``H+Y@`&"R/\6].E``$+810!J@8(
M`/DA``(+(0`$"P$4`*FA3T'Y``%`^2```,J```"U_7M`J?^#"I'``U_62_K_
ME_U[O*G]`P"1\U,!J?5;`JGW8P.I@`8`M*(``-!"]$?Y6`!`^1@&`+0"`$`Y
M%0"`4E_T`'%$&$!Z`0,`5!,#0/GS`0"T]P,!JO8#`*JU?D"3]`,8JN`#$ZKB
M`Q6JX0,6J@KZ_Y>````U8&IU.!_T`'%``@!4DXY`^//^_[7@`Q.J\U-!J?5;
M0JGW8T.I_7O$J,`#7]8?(`/5]0,`JJ(>0#A?]`!Q1!A`>J'__U2U`@!+X___
M%Q\@`]6``AC+M08`D0#\0Y/@`@"Y<P(5B^`#$ZKS4T&I]5M"J?=C0ZG]>\2H
MP`-?UA,`@-+E__\7'R`#U?U[O*G]`P"1]5L"J;8``-#S4P&ILP``T/4#`*K`
MVD?Y<_9'^;33`)$!`$#YH1\`^0$`@-+A`Q2JX`,5JK7__Y?@`0"THS>`N6("
M0/E`#`.+`01`^4%X(_CA_O^T`"``D0$$0/D!``#YH?__M>$#%*K@`Q6JI___
MEV#^_[76VD?YH1]`^<`"0/D@``#*H```M?-30:GU6T*I_7O$J,`#7];F^?^7
M'R`#U?U[N:G]`P"1\U,!J?,#`:KU6P*IM0``T/=C`ZGT`P"J^6L$J?LK`/FA
MVD?Y8`)`.2(`0/FB-P#Y`@"`TA_T`'%S%I.:X`,3JE[Y_Y?W`P"JH9,!D>`#
M%*J$__^7(`@`M/8#`*I7^?^7_P(`Z^D&`%2V9X"YN0``T-;R?=.``D`Y'_0`
M<0080'H@#`!4X0,4JB`<0#@?]`!Q!!A`>J'__U0A`!3+(7Q`DSGW1_G@"@"1
M```!BS<#0/E^^?^7X&HV^``+`+2C9X"Y@`8`D2(#0/F!`D`Y0GAC^#_T`'$D
M&$!Z00``.<```%0!%$`X01P`.#_T`'$D&$!Z@?__5$$$`)&@!X!20```.6`6
M0#@@%``XP/__-0``@%*UVD?YHC=`^:$"0/E!``'*`0@`M?-30:GU6T*I]V-#
MJ?EK1*G[*T#Y_7O'J,`#7]8``(#286I@.,%J(#@`!`"1H?__->[__Q>Y``#0
M(/='^18`0/G``D#Y(`4`M.$#%JH``(!2`@``%.`#&"HBC$#X&`0`$:+__[4`
M#``1`'Q]DZ$``/`BB$"YP@$`-.$#`*K@`Q:J<?G_ER'W1_D@``#Y0`,`M!M_
M0)/Z`P"J=O-]TWL'`)%?>SOXN&<`N:K__Q<B`(!2(H@`N33Y_Y?Z`P"JP`$`
MM!M_0)/A`Q:J=O-]T^(#%JKI^/^7(/='^1H``/GP__\7`0"`TJ;__Q<``H#2
M&`"`4M___Q<``(`2O?__%UKY_Y<?(`/5_7NRJ?T#`)'U6P*IM0``T/-3`:GW
M8P.I^6L$J:':1_DB`$#YHF\`^0(`@-*```"T`0!`.?8#`*J!`0`UM=I'^:%O
M0/F@`D#Y(```RL`(`+7S4T&I]5M"J?=C0ZGY:T2I_7O.J,`#7];F^/^7]P,`
MJF#^_[08``#0N6,!D1BC#I'4!8!2X`,7JGKY_Y>@!0"T`4Q`.8$"`6OA``!4
M`5!`.2'__S2!`@%KX0,!2T$``%0!5$`Y@?[_-!-,`)'@`Q:JM/C_E_H#`*K@
M`Q.JL?C_EP``&@L`"``1`'Q`D^GX_Y?E`Q.JY`,6JN,#&*KZ`P"J`@"`DB$`
M@%*J^/^7X@,9JN$#&JH``(!2KOC_EQ\$`#&@``!4H&M`N0`,%!(?$$!QP`$`
M5.`#&JJ&^?^7X`,:JDCY_Y?@`Q>J3OG_EZ#Z_[7@`Q>J`_G_E^`#%JHM^?^7
MN___%Q\@`]7@`QJJJ?__E_/__Q?_^/^7_7N^J?T#`)'S4P&ILP``T/0#`*IS
MSD?Y8`)`N>OX_Y<"``B1X0,4J@``@%(K^?^7P```-```@%+S4T&I_7O"J,`#
M7]8?(`/58`)`N=_X_Y<`$$*Y``P4$A\00''@``!48`)`N=GX_Y<`$$*Y``P4
M$A\H0'$!_O]400"`4N`#%*KR^/^7'P``<>`7GQKS4T&I_7O"J,`#7]80"H+2
M_V,PR^+_@=+]>P"I_0,`D?-3`:FT``#0]5L"J;4C`9'W&P#Y]@,`JH/:1_D`
M``#0]P,!J@#`#I%D`$#YI"<(^00`@-+A`Q6J8?C_EQ\``'$-!`!4`P0`4:'*
M8SB!`P`TXP,`*G-\0)/A!8!2X@,3JN`#%:H:^?^7P`(`M*```-``S$?Y``!`
MN:GX_Y?C`Q.JX@,5JN$#%JH9^?^7E-I'^:$G2/F``D#Y(```RB`"`+7S4T&I
M$`J"TO5;0JG]>T"I]QM`^?]C,(O``U_6P_S_-:```-``S$?Y``!`N93X_Y?B
M`Q>JX0,6JG'X_Y?L__\7F_C_E_U[OZF@``#0_0,`D0#,1_D``$"YB?C_EZ(`
M`-`#``#0_7O!J`$``-!"R$?Y8\`-D2$`#Y'!^/\7_7N^J?T#`)'S"P#YLP``
MT'/.1_E@`D"Y>OC_E^O__Y=@`D"Y=_C_E_,+0/G]>\*H!```T(1@')$"``"P
M`0``T`4`@%+C`P2J0D`ZD2&`#Y'(^/\7'R`#U1`*A-+_8S#+_7L`J?T#`)'S
M4P&IM```T/5;`JFSXP"1@-I'^0$`0/FA)Q#Y`0"`TB[X_Y?D`P`J!0``T`,`
M`-`B`(+2I>`/D6,`$)$A`(!2X`,3JO'W_Y<`!/@W``B"TK8#`(L"`(+2X`,3
MJN$#%JKV]_^7\P,`J@`#^#<`!``1`'Q`DQWX_Y?U`P"JP```M'-^0)/A`Q:J
MX@,3JL_W_Y>_:C,XE-I'^>`#%:JB)U#Y@0)`^4$``<I!`0"U\U-!J1`*A-+U
M6T*I_7M`J?]C,(O``U_6'R`#U14`@-+R__\7/OC_EQ\@`]7&__\7'R`#U1`.
M@M+_8S#+_7L`J?T#`)'U6P*IM@``T/-3`:GU`P&J]V,#J?,#`*KY:P2IH9,!
MD?LK`/D```#0PMI'^0!@$)%#`$#YHS<(^0,`@-+=_?^7]`,`JN$%@%+@`Q.J
M=_C_EX`"`+0```#0X0,3J@"@$)$Z_O^7X`,3JM;:1_FB-TCYP0)`^4$``<HA
M#`"U\U-!J1`.@M+U6T*I]V-#J?EK1*G]>T"I^RM`^?]C,(O``U_6X`,3JIGW
M_Y<7``#0^@,`*N'B$)'@`Q6JD/?_E_L#`*J@_/^T8`-`.1D``-`8``#0.0,1
MD1@C$9&UHP&1@`8`-+0``+3A`QNJX`,4JAOX_Y<`!0`TX`,;JH3W_Y=APR"+
M(?!?.#^\`''A``!4``0`46'#((M_RR`X(?!?.#^\`'%@__]400<`$2````L?
M_#]Q+/G_5.0#&ZJ[``#0`@""TB$`@%+F`Q.JY0,9JN,#&*K@`Q6J<??_EWO/
M1_E@`T"YTO?_EP(`")'A`Q6J``"`4G+W_Y?@```U8`-`N<OW_Y<`$$*Y``P4
M$A\@0'$@`@!4X>(0D0``@-)8]_^7^P,`JJ#U_[1@`T`YP/G_-1L``-![0Q"1
MM```M.$#&ZK@`Q2JYO?_EV#^_S0@`(!2UO__%R$`@%+@`Q6JU/?_EZ#]_S7A
M`Q6J````L`"@$)'7_?^7X`,5JFWW_Y><__\7M_?_EP$`0#G!```T`@0`D3^\
M`'$`$(*:011`.*'__S7``U_6_7N^J?T#`)'S4P&I8`,`M!0`0#GS`P"J%`,`
M-#/W_Y<`!`#18@(`BW\"`NMB!`!48&I@.!^\`'&@``!4'```%$``0#D?O`!Q
M(0,`5$($`-%_`@+K8?__5)^^`''@``!4\U-!J0```+#]>\*H```1D4;W_Q<?
M(`/50`"`TE?W_Y<`!0"T`@``L$)`$)%"`$!Y`@``>?-30:G]>\*HP`-?UD``
M0#D?O`!Q@`$`5$($`-%_`@+K8___5'\"`NO@_/]40@0`T7\"`NOB``!40`!`
M.1^\`'&!``!40@0`T7\"`NMC__]40@`3RT`(`)$?!$#QB`$`5*```-`4H`*1
MX0,3J@,`@M)"!`"1X`,4JC?W_Y?@`Q2J\U-!J?U[PJC``U_6``"`TO-30:G]
M>\*HP`-?UOU[N*D!``"P(<`-D0```+#]`P"1\U,!J2)``)&S``"P]5L"J28<
M0:GW8P.I)!1"J:8?!:EAVD?Y`$`1D4)`0'D6``"PHN,`>2(`0/FB/P#Y`@"`
MTJ07!JD7``"P&```L!0``+`[_?^7E,(2D0```+``@!&1-_W_E[4S`9$```"P
M`*`1D3/]_Y<```"P`.`1D3#]_Y?``A*1+OW_EP```+``0!*1*_W_E^!B$)$I
M_?^7`(,2D2?]_Y?@`Q2J)?W_EP```+```!.1(OW_EP```+``H!"1'_W_EP``
M`+#A`Q6J`$`3D=_\_Y>```"TX0,`JN`#%*I!_?^7````L.$#%:H`H!.1U_S_
MEZ```+0"``"PX0,`JD``%)$X_?^7````L.$#%:H`0!21SOS_EV`"`+3A`P"J
MX&(0D3#]_Y<!``"PP`(2D2$@%9$L_?^7<]I'^:$_0/E@`D#Y(```RH`#`+7S
M4T&I]5M"J?=C0ZG]>\BHP`-?UA\@`]4```"PX0,5J@"`%)&W_/^7P```M.$#
M`*H`@Q*1&?W_E^G__Q<?(`/5`0``L+1#`9%"`8#2(>`4D:"'`9'-]O^7(/S_
M-8%N`)$`@Q*1#?W_E]W__Q?O]O^7_7N]J?T#`)'S4P&ILP``L+0``-!AVD?Y
M@!)`N2(`0/FB%P#Y`@"`TA\$`#$@`0!4<]I'^:(70/EA`D#Y00`!RJ$"`+7S
M4T&I_7O#J,`#7]8```"PH9,`D0"`$I&-_/^70`$`M`$`0#D_P`!QX`>?&C\`
M`''A!Y\:```!"H`2`+GL__\7'R`#U0``@%*`$@"YZ/__%\GV_Y?]>[^I_0,`
MD6KV_Y?I]O^7@```M```0/G]>\&HP`-?U@``@-+]__\7_7N[J?T#`)'S4P&I
MLP``L/5;`JD5``"P]QL`^;="%9%BVD?Y]@,`JJ$3`9'@`Q>J0P!`^:,G`/D#
M`(#29?S_ET`"`+0!`$`Y]`,`JN$!`#3A`Q:J&??_EP`"`+1SVD?YH2=`^6`"
M0/D@``#*(`0`M?-30:GU6T*I]QM`^?U[Q:C``U_6'R`#U>$#%JJ@0A61MOS_
ME_+__Q?@`Q:J(_;_E_4#`*K@`Q2J(/;_EZ`"`(L`"`"16?;_E^8#%*KD`Q:J
M!0``L`,``+"EX!"18R`1D0(`@)+U`P"J(0"`4A?V_Y?A`Q6JX`,7JJ#\_Y?<
M__\7@O;_EQ\@`]40.I#2_V,PRZ$``-`A0`"1!`20TOU[`:G]0P"1I0,$BR:<
M0*GW8P2IN```L/5;`ZGY:P6I]@,`JO-3`JFU,P*1^W,&J1H``+``VT?Y(@Q"
MJ0@`0/FHS`#Y"`"`TJ8?":DD%$2IH@\,J28<0ZFF'PVI(@Q%J:07#JD@#$#Y
MH%,`^2`P0/GA`Q6JH%\`^4!C$)&BCPJI$?S_EX```+0!`$`Y\P,`JN$A`#6.
M__^7$P"`TO0#`*JWHP*1``\`M.`#%*K<]?^7`/A_TP`$`)$5]O^7A`)`.?<#
M`*J$`0`T````L/,#%ZH9H!61X`,3JN,#&:H"`("2(0"`4M+U_Y=S"@"1A!Y`
M."3__S6@8T#Y(`(`M+0C`Y$#```4@(9`^*`!`+3A`Q6J[?O_E_,#`*I@__^T
M`0!`.2'__S0T_?^7X/[_-.`#$ZKC]?^7\P,`JL`!`+6Y0P*1%`"`4C/;=/@S
M`0"T8`)`.>```#3@`Q.J)_W_EX`*`#64!@`1,]MT^#/__[43`(#2X`,3JJKU
M_Y?[`P"JX`,7JJ?U_Y<;`!L+>Q,0$7M_0)/@`QNJWO7_E^<#%ZKD`Q.J`0``
ML`8``+`E`!&1QL`5D0,``+!CX!61`@"`DO0#`*HA`(!2FO7_EP$X@%+@`Q2J
M@_;_EQ\$`#%@!P!4LP``L'/.1_E@`D"Y]?7_EP(`")'A`Q2J``"`4C7V_Y?W
M`P`J(`@`-*```+##`D#Y`@``L.0#%*H`Q$?Y0F`8D2$`@%(3`(#2``!`^0WV
M_Y<8VT?Y`020TJ$#`8O@`Q.J(LQ`^0$#0/E!``'*@3@`M?-30JD0.I#2]5M#
MJ?=C1*GY:T6I^W-&J?U[0:G_8S"+P`-?UA\@`]62]?^7]`,`JF#Q_[5S(@"1
MX&IS^,`2`+3A`Q6JC?O_EV#__[0!`$`YP?[_-7,B`)'X__\7'R`#U>`#$ZJ4
M!@`1@O7_E_,#`*I`]/^TK/__%S[V_Y<%`$"YOT0`<6#X_U2@``"PPP)`^0(`
M`+#D`Q2J`,1'^4(@%I$A`(!2$P"`T@``0/G9]?^7S/__%Q\@`]5@`D"YK?7_
MEP`00KD`#!02'Q!`<6'W_U1@`D"YI_7_EQP80KE5]?^7GP,`:Z'V_U1@`D"Y
MH?7_EP`00KD`(``2'P`'<>'U_U3@`QNJ;_7_E^$#%:KS`P"J````L`!`&)%8
M^_^7H`P`M-4"0/E3]?^7X0,`JN`#%:IB_?^7]0,`JL`+`+3@`Q6J)/7_E_L#
M`*H?#`!Q[0$`5`!\0),!``"P`!``T2$@%Y&@`@"+K_7_EP`!`#5_$P!Q`"8`
M5&`3`%&@PB"+`/!?.!^\`'%@)0!4F/[_E\```#4!`(!2X`,5JN;U_Y>@?P"Y
MP`@`-0$``+````"P(2`5D0"`$I&7^_^7%0``L````+`9`!&1]@,9JK7B%Y$Y
M]?^7Y@,`*@<``+#G8!R1`P``L/L#!ZICH!>1Y0,9JN0#%*H"`("2(0"`4N`#
M$ZKY]/^7$@``%!\@`]7:]?^7``!`N1]$`'%!`@!4)O7_E_L#`/GW!@`1Y@,`
M*N<#%RKE`Q:JY`,4JN,#%:H"`("2(0"`4N`#$ZKG]/^7`3B`4N`#$ZK0]?^7
M'P0`,8#]_U3@`Q2JC/7_E^$#$ZI`8Q"1:?O_E^`#$ZJ-_O^76O__%Q\@`]6*
M_O^7X`,3JOKT_Y?S`P"J5/__%Z`!@-(*]?^7%```L/<#`*ID"H!2E((5D?3^
M_Q?5`D#YHO__%T(`@%(A`H"2)/7_E[OC!I&@?T"YP@"`TN$#&ZJ/]?^7H.-&
M.8```#6@YT8Y'PP!<>`=`%2@?T"Y`0"`T@(`@%*WPP.1O*,$D13U_Y>__Q&I
M('&5TB%@A-*@^;WRH>BL\J$##ZG`CHK20`:B\L&?F])!%[/RH0,0J0`^G-*_
M:P&Y0'JX\J"+`/G@X@"1H#L`^:!_0+D"`)#2X0,;JF_U_Y?C`P"J'P``<?8#
M`"K-"`!4HH]`^6!\0)-!#``+7P`!ZZ*30/E)``!40@0`D4!T0(NA@Q&IH&M!
MN<`4`#0!"(!2-@``2W\`%FNA.T#Y=M"6&J,W`/G9?D"3(,`@B^(#&:KA`QNJ
M>?3_EZ!K0;FC-T#YP`(`"Z!K`;D?``%QH?O_5'8`%DMY`QF+X`,7JD_V_Y??
M_@!QS0(`5-8"`5'`?@93H&L`N15D&E.U`@&1-0,5BR8?0*F&'P"I)!=!J807
M`:DB#T*I@@\"J2@G0ZF()P.IX`,7JCD#`9$\]O^7OP(9ZX'^_U2@:T"YUAH`
M2Z`[0/D#"8#2PGY`D^$#&:J3]/^7MFL!N:!_0+D"`)#2X0,;JBKU_Y?C`P"J
M'P``<?8#`"J,]_]4H']`N<ST_Y>UVU&IX0^`$J`B0].!RR`X``0`$1_@`'%L
M#@!4X>(`D0('@%)"``!+(,`@BT)\0),!`(!2FO3_E\'^6-/`_E#3H8,%.:'^
M6-.@AP4YP/Y(TZ"+!3F@_E#3H)<%.:#^2-.VCP4YNR,&D:&3!3GV`QNJM9\%
M.7RC`)&@FP4YX`,7J@?V_Y>WQP61IA=/J0```+"C"U"I%:`5D<#\4-.@QP4Y
MH/Q8TZ#3!3F@_%#3H-<%.6#\6-.ABT#YH.,%.6#\4-.@YP4Y0/Q8TZ#S!3E`
M_%#3H/<%.2#\6-/$?!A3IL\%.:7?!3G&_$C3H^\%.:7\2-.B_P4Y8_Q(TZ$/
M!CE"_$C3H`,&.2#\4-.DPP4Y(?Q(TZ;+!3FEVP4YH^L%.:+[!3F@!P8YH0L&
M.0(``!3D%D`XX`,6JN,#%:H"`("2(0"`4M8*`)$&]/^7GP,6ZP'__U0'``"P
MY@,;JN=@')$#``"PO\,&.>0#%*IC8!>1````L`4`$9$"`("2(0"`4N`#$ZKW
M\_^7X`,4JJ'T_Y?A`Q.J0&,0D7[Z_Y?@`Q.JHOW_EV_^_Q?Y`QNJ;___%]8&
M0/FVVO^TX`,6JN7S_Y<?#`#Q*=K_5``0`-$!``"PP`(`BR%`%Y%R]/^7'P``
M<;42EIK)_O\7`@B`4D(``$M"?$"3`0"`4OOB`)%@PR"+*/3_E^`#%ZJF]?^7
MH(,$D1_\`*G__@2I__X%J?\V`/F'__\7H.M&.1\$`7$!XO]4H.]&.1\,`7&A
MX?]4H/-&.1\@`7%!X?]4H/=&.1\4`7'AX/]4M7]`N4(`@%(A!X"2X`,5*AOT
M_Y?A`QNJ(@6`TN`#%2J']/^7!P``L.8#&ZH#``"PYV`<D;C__Q<E]/^7_7NX
MJ?T#`)'W8P.IN```L*#3`9'S4P&I]5L"J?4#`*H3ST?YH#<`^:```+#Y:P2I
M^W,%J0#81_D!`$#YH3\`^0$`@-)@`D"Y!O3_E_0#`*I@`D"Y`_3_EP#@0CF`
MY@(YX0,5J@```+```!*1O_G_EX```+0!`$`Y/\0`<>`2`%2B_/^7%L]'^;L`
M`-#``D"Y]//_EP$``+!C`8!2(@"`4B'`&9$#]/^78`8`M'4C`I$!"$#YH`9`
MN3<40/D?!`!QK04`5!F`@%(4`(!2,P"`4AD$H'(*```400A`^>`#&JH,]/^7
MX`,`-:`&0+ES!@`1E`8`$1\`$VN-`P!4P`)`N=CS_Y<#`(!2@GY`D^$#%ZHX
M]/^7_`,`JD`"`+0"`$#YHP9`^4`,0+EZV'/X```9"A\`$'$@_?]4P`)`N<GS
M_Y>!`T#Y0P"`4@(`@-*U\_^7X0,`JN`#&JKN\_^78/S_-&`C`I$`!$"Y`00`
M43\`%&O`"P!4%,]'^8`"0+FY\_^7`0``D&,`@%(B`(!2(>`9D<CS_Y?S`P"J
M@`$`M(`"0+FP\_^780I`^0(``)!"`!J1(0!`^8OS_Y=@"D#Y``!`^0`,0+G@
M#+`W%,]'^8`"0+FD\_^7`0``D&,`@%(B`(!2(2`:D;/S_Y?S`P"JH`$`M*$W
M0/D```"0`*`0D5OY_Y?U`P"J@`)`N=4)`+25\_^780I`^>(#%:HA`$#Y<?/_
MEQC/1_ET(P*1``-`N8WS_Y?S`P"J``-`N8KS_Y<B`(!2`0``D"%`&I&^\_^7
M`@``D.$#`*I"H!J1X`,3JF'S_Y<``T"Y?_/_EQ_D`CFA-T#Y````D`!@$)$\
M^?^7@`H`^?,#`*K@!`"T`3B`4N`#$ZK\\_^7`00`$3\$`'$$B%%ZX08`5*``
M`)`:V$?YH3]`^4`#0/D@``#*``8`M?-30:GU6T*I]V-#J?EK1*G[<T6I_7O(
MJ,`#7]8`!$`Y0.W_-&C__Q<?(`/5'P0`<4WT_U05ST?Y=","D3,`@%*@`D"Y
M<P8`$5?S_Y?A`Q>J#?/_EX`&0+D?`!-K+/__5);__Q>`!D#YV_S_EX`*`/GS
M`P"JP/K_M0```)``P!J1A?/_ETCS_Y=@(P*18@I`^0$$0/E``$#Y(0!`^7;Z
M_Y>Q__\7@`)`N3_S_Y=A"D#Y(0!`^9#S_Y>5__\71O/_EWLC`I$!``"0XP,`
M*B!@&Y'B`Q.J80=`^2$`0/EN\_^7'R`#U?U[OJG]`P"1\U,!J?0#`*J*^_^7
M`0!`.<$"`#0"!`"1\P,`JC^\`'%S$H*:011`.*'__S5!_/^7GP(`\0080'H@
M`0!4@`)`.>```#0!``"0X`,3JB'`%9&6\_^7?P(`Z\```%3S4T&I_7O"J,`#
M7];S`P"J\/__%^`#%*KS4T&I_7O"J,/Y_Q>C``"08]Q'^8,``+1C`$#YQO+_
M%Q\@`]4#`(#2P_+_%_U[O*G]`P"1]5L"J;4``)#S4P&IM6(LD;0``)"4@BR1
ME`(5R_=C`ZGV`P*J^`,`*O<#`:J4_D.3=O+_EU0!`+03`(#2HWIS^.(#%JKA
M`Q>JX`,8*G,&`)%@`#_6GP(3ZR'__U3S4T&I]5M"J?=C0ZG]>\2HP`-?UL`#
M7];]>[^I_0,`D?U[P:C``U_6``````$``@``````<&5R;'AS:2YC````````
M`%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@```````````E<R\E
M<P```"]P<F]C+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D
M97(``````$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````&5X90``````+W!R;V,O
M)6DO)7,``````"X`````````4$%27U1%35```````````%!!4E]04D]'3D%-
M10`````Z`````````"\`````````)7,E<R5S``!015),-4Q)0@``````````
M4$523$Q)0@!015),-4]05```````````4$523$E/``!005)?24Y)5$E!3$E:
M140`4$%27U-005=.140``````%!!4E]#3$5!3@````````!005)?1$5"54<`
M````````4$%27T-!0TA%`````````%!!4E]'3$]"04Q?1$5"54<`````````
M`%!!4E]'3$]"04Q?5$U01$E2`````````%!!4E]435!$25(```````!005)?
M1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@``````````4$%27T-,14%.
M/0```````#$`````````3$1?3$E"4D%265]0051(`%-94U1%30``)3`R>```
M``!P87(M`````"5S)7,E<R5S```````````E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````
M<&%R;``````N<&%R`````"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S
M````)7,E<W1E;7`M)74M)74E<P``````````4$%42``````E<SH@<')I=F%T
M92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET
M(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````05)'5@`````8````
M`````'!E<FP`````,`````````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q
M+C`S-P```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y````````
M```E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*```````````E<P```````"UE````````
M+2T```````!54T52`````%5315).04U%``````````!435!$25(``%1%35!$
M25(`5$5-4`````!435```````"]T;7``````979A;"`G97AE8R`O=7-R+V)I
M;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@
M=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)'!A<E]T
M96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%2
M7T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I
M;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M
M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN
M9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?
M=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D
M7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*
M5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE
M.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@
M/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<
M)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD
M("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R
M(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B([
M"F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF
M:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS
M>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E
M<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]
M"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE
M9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV
M*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@
M/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G
M.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y
M9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^
M("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE
M*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O
M<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(
M+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B
M=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D;V9F<V5T(#T@-3$R
M.PIM>2`D:61X(#T@+3$["G=H:6QE("@Q*0I["B1O9F9S970@/2`D<VEZ92!I
M9B`D;V9F<V5T(#X@)'-I>F4["G-E96L@7T9(+"`M)&]F9G-E="P@,B!O<B!D
M:64@<7%;<V5E:R!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A73L*;7D@)&YR
M96%D(#T@<F5A9"!?1D@L("1B=68L("1O9F9S970["F1I92!Q<5MR96%D(&9A
M:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=('5N;&5S<R`D;G)E860@/3T@)&]F
M9G-E=#L*)&ED>"`](')I;F1E>"@D8G5F+"`B7&Y005(N<&U<;B(I.PIL87-T
M(&EF("1I9'@@/CT@,"!\?"`D;V9F<V5T(#T]("1S:7IE('Q\("1O9F9S970@
M/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T("H](#(["GT*;&%S="!U;FQE<W,@)&ED
M>"`^/2`P.PHD;V9F<V5T("T]("1I9'@@+2`T.PIS965K(%]&2"P@+21O9F9S
M970L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@+21O9F9S970@
M+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0["B1D
M871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T.PIW
M:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E
M860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE
M(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN
M+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI
M+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D
M8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F
M+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD
M969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O
M:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U
M9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]
M("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65]
M(#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL
M:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N
M86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D[
M"F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER
M95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[
M)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE
M(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A
M;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T
M=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL96YA;64@
M/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["FUY("1K
M97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN97AT('5N;&5S
M<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["GT@;W(@<F5T
M=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U
M;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL
M93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@
M9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL96YA;64M/GMB
M=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY
M("1F:6QE;F%M92`](%]T96UP9FEL92@B)&9I;&5N86UE+3Y[8W)C?2YP;2(L
M("1F:6QE;F%M92T^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA
M;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E
M*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE
M9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM
M>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2![
M"G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$
M4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER
M92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I
M;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R
M97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q
M(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]
M"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A
M8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI
M=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T
M(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@
M;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*
M;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L
M;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I
M9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G
M*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@
M0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A
M9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!
M24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@
M>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2![
M"F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T
M($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@
M)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]
M"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF
M("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG
M*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T
M(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?
M;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES
M=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN
M8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH
M*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@
M0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]
M"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R
M8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP
M.PII9B`H9&5F:6YE9"`D<&%R*2!["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3
M:7IE*#$R."HQ,#(T*3L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@
M(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L97-S
M*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*
M*"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R<F]R
M.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A
M(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N
M*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O
M7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*:68@
M*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B
M)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@82!0
M05(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#<F5A
M=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*
M24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@
M24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I;FUO
M9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O
M<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C86QA
M<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@
M/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L
M;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I
M('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@
M)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]0
M05)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C
M*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD
M;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S
M970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD968[
M"FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO
M9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L*
M*"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI
M8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`
M1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM
M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R
M:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE
M+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@
M/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?.PIL
M87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L*
M*"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>
M+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@/2`D
M4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I
M(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B*2![
M"B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*
M?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[
M)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<
M+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG("(I
M+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI
M"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]
M("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE
M(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I
M.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"FEF("$D
M14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L
M*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<
M)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S
M("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A
M8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN
M=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O
M;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H
M*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M
M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@
M/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE
M(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W
M*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z
M.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$
M:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D
M1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N
M(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M
M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D
M8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN;6]D92@D9F@I
M.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD8V%C:&5?
M;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["GT*)&-A
M8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D[
M"B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA
M;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H
M)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PHD9F@M/F-L
M;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@
M9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@
M4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER
M92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&:6QE+3YN97<[
M"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`
M(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PIP=7-H
M($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA
M;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ
M<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T
M:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S
M("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R
M7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E
M<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E
M<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>
M+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA
M;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT
M<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M
M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B
M)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E
M<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M
M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R86-T
M5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA
M;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,
M:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6
M.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L
M92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;
M+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@
M>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY
M("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF
M:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H
M.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[
M(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L
M97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E
M(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR
M97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V
M>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ
M5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR
M97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/
M.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI
M=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@
M871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U
M:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE
M=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![
M(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E
M<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@
M>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY
M("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2
M(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI
M('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD
M("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P
M=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E
M9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN
M,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S
M97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U53
M15).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M
M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D
M96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T
M;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I
M;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\
M(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L
M(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F
M:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<
M,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D
M8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@
M)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]
M('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R
M<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B
M(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D
M9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F
M:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O;F9I
M9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z
M("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,
M14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D
M(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I
M<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]4
M14U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M
M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY
M("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F
M=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E
M;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I=&4@
M)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O;G1E
M;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F
M:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U
M;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?
M<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345]
M(&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M
M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0
M?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@
M>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N
M86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]0
M4D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI
M(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR
M971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?
M97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*
M?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E
M<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?
M5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<
M421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II
M9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X
M97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@
M?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D
M.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z
M.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P
M=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM
M?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345]
M(#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6
M>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92![
M"B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%
M1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P
M("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U0
M1$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D
M14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/
M0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.
M7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L
M971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!
M4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L
M96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]
M("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@
M;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@
M)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B
M(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D
M969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E
M>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R
M8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E
M(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP
M;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R
M;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O
M<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%
M.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID
M:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%
M.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$
M7U\*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!H)````````"`D```````````````````!````````
M``$``````````0````````#?`0````````$`````````+@(````````!````
M`````(D#````````#`````````#H'`````````T`````````5%,````````9
M`````````!B;`0``````&P`````````(`````````!H`````````()L!````
M```<``````````@`````````]?[_;P````!@`@````````4`````````N`T`
M```````&`````````%`#````````"@`````````(!0````````L`````````
M&``````````5`````````````````````P````````!0G0$```````(`````
M``````8````````4``````````<`````````%P````````#H%@````````<`
M`````````!0````````(`````````.@"````````"0`````````8````````
M`!X`````````"`````````#[__]O``````$```@`````_O__;P````"@$P``
M`````/___V\``````P````````#P__]O`````,`2````````^?__;P`````1
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````!T`````````'0`````````=````````
M`!T`````````'0`````````=`````````!T`````````'0`````````=````
M`````!T`````````'0`````````=`````````!T`````````'0`````````=
M`````````!T`````````'0`````````=`````````!T`````````'0``````
M```=`````````!T`````````'0`````````=`````````!T`````````'0``
M```````=`````````!T`````````'0`````````=`````````!T`````````
M'0`````````=`````````!T`````````'0`````````=`````````!T`````
M````'0`````````=`````````!T`````````'0`````````=`````````!T`
M````````'0`````````=`````````!T`````````'0`````````=````````
M`!T`````````'0`````````=`````````!T`````````'0`````````=````
M`````!T`````````'0`````````=`````````!T`````````'0`````````=
M`````````!T`````````'0`````````=`````````!T````````PFP$`````
M`%!3````````````````````````````````````````````````````````
M``````````````````````````````````````B@`0````````````````#8
M4@``````````````````("$`````````````````````````````````````
M````````````````````````"*`!``````#_____`````'!7````````$%0`
M``````````````````!5````````4%<```````!85P```````&!7````````
M:%<``````````````````#A7````````0%<``````````````````'A7````
M````1T-#.B`H56)U;G1U+TQI;F%R;R`V+C0N,"TR=6)U;G1U,2D@-BXT+C`@
M,C`Q-S`W,C0`1T-#.B`H56)U;G1U+TQI;F%R;R`V+C0N,"TQ=6)U;G1U,BD@
M-BXT+C`@,C`Q-S`W,#0``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT
M86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS
M='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L
M82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;64`+FEN
M:71?87)R87D`+F9I;FE?87)R87D`+FIC<@`N9'EN86UI8P`N9V]T`"YD871A
M`"YB<W,`+F-O;6UE;G0`````````````````````````````````````````
M```````````````````````````````````````````````+`````0````(`
M``````````(``````````@```````!L````````````````````!````````
M````````````$P````<````"`````````!P"````````'`(````````@````
M````````````````!````````````````````"$````'`````@`````````\
M`@```````#P"````````)`````````````````````0`````````````````
M```T````]O__;P(`````````8`(```````!@`@```````.P`````````!0``
M```````(````````````````````/@````L````"`````````%`#````````
M4`,```````!H"@````````8````#````"``````````8`````````$8````#
M`````@````````"X#0```````+@-````````"`4```````````````````$`
M``````````````````!.````____;P(`````````P!(```````#`$@``````
M`-X`````````!0`````````"``````````(`````````6P```/[__V\"````
M`````*`3````````H!,```````!@``````````8````#````"```````````
M`````````&H````$`````@``````````%``````````4````````Z`(`````
M```%``````````@`````````&`````````!T````!````$(`````````Z!8`
M``````#H%@`````````&````````!0```!4````(`````````!@`````````
M?@````$````&`````````.@<````````Z!P````````4````````````````
M````!````````````````````'D````!````!@``````````'0`````````=
M````````(`0``````````````````!``````````$`````````"$`````0``
M``8`````````("$````````@(0```````#0R```````````````````(````
M````````````````B@````$````&`````````%13````````5%,````````0
M````````````````````!````````````````````)`````!`````@``````
M``!H4P```````&A3````````2$````````````````````@`````````````
M``````"8`````0````(`````````L),```````"PDP````````0`````````
M```````````$````````````````````H@````X````#`````````!B;`0``
M````&)L````````(````````````````````"``````````(`````````*X`
M```/`````P`````````@FP$``````"";````````"```````````````````
M``@`````````"`````````"Z`````0````,`````````*)L!```````HFP``
M``````@````````````````````(````````````````````OP````8````#
M`````````#";`0``````,)L````````@`@````````8`````````"```````
M```0`````````,@````!`````P````````!0G0$``````%"=````````L`(`
M``````````````````@`````````"`````````#-`````0````,`````````
M`*`!````````H````````(`````````````````````(````````````````
M````TP````@````#`````````("@`0``````@*`````````H$```````````
M````````"````````````````````-@````!````,```````````````````
M`("@````````9@````````````````````$``````````0`````````!````
M`P````````````````````````#FH````````.$````````````````````!
/````````````````````
